@@ -3,8 +3,8 @@
   FILE: 
   CREATOR: eric 25 June 2000
   
-  $Id: testmime.c,v 1.5 2005/12/13 10:27:21 tml Exp $
-  $Locker:  $
+  $Id: testmime.c 543 2005-12-13 10:27:21Z tml $
+  $Locker$
     
  The contents of this file are subject to the Mozilla Public License
  Version 1.0 (the "License"); you may not use this file except in
