@@ -43,7 +43,7 @@
 #include "db_config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: hash_open.c 7595 2007-01-29 12:46:59Z pchen $";
+static const char revid[] = "$Id: hash_open.c 2904 2003-11-20 22:14:35Z toshok $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -409,7 +409,7 @@ __ham_new_file(dbp, txn, fhp, name)
 			goto err;
 	} else {
 #ifdef DIAGNOSTIC
-		memset(buf, 0, dbp->pgsize);
+		memset(buf, dbp->pgsize, 0);
 #endif
 		page = (PAGE *)buf;
 	}
